==> dde-launchpad_1.99.11.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_et.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="et">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Avast</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Liigata pinnale</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Liiguta üles edasi</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Eemalda suurte käivatest</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Lisa suurte käivatesse</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Eemalda töölaualt</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Väljastage töölaual</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Eemalda dokkist</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Väljastage dokkisse</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Eemalda käivitamisega</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Lisa käivitamisega</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Kasuta proksi</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Keela näidiskülgede suurendamine</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Eemalda</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Makse</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Otsing</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Koko ekraani režiim</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Installi</translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Käsitavad kohalikult</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="163"/>
        <source>Window Mode</source>
        <translation>Aken režiim</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Vigla</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Muusika</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Vide</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Võtmed</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation>Mängud</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Tööriistad</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Lugemine</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Arendus</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Süsteem</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Muidud</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Oled kindel, et soovid eemaldada %1?
</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Loege välja</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Kinnita</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Uuesti installitud</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Kõik rakendused</translation>
    </message>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="556"/>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Otsingutulemusi pole</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Vaba järjendamine</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sorteeri kategooriate järgi</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sorteeri nime järgi</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Järjendamise režiim</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Arvutiga</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Pildid</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Dokumentid</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Töölaud</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Kontrollkeskus</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <location filename="../package/launcheritem.qml" line="111"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="113"/>
        <source>Chat</source>
        <translation>Väline</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="115"/>
        <source>Music</source>
        <translation>Müük</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="117"/>
        <source>Video</source>
        <translation>Vide</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="119"/>
        <source>Graphics</source>
        <translation>Vaatlejad</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="121"/>
        <source>Games</source>
        <translation>Mängud</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="123"/>
        <source>Office</source>
        <translation>Tööriistad</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="125"/>
        <source>Reading</source>
        <translation>Lulemine</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="127"/>
        <source>Development</source>
        <translation>Arendus</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="129"/>
        <source>System</source>
        <translation>Süsteem</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="131"/>
        <source>Others</source>
        <translation>Muidu</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="162"/>
        <source>launchpad</source>
        <translation>Lähtepunkt</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="299"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Oled kindel, et soovid eemaldada %1?
</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="311"/>
        <source>Cancel</source>
        <translation>Loetelu lõpetamine</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="325"/>
        <source>Confirm</source>
        <translation>Kinnita</translation>
    </message>
</context>
</TS>

==> dde-launchpad_1.99.13.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_et.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="et">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Avast</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Liigata pinnale</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Liiguta üles edasi</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Eemalda suurte käivatest</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Lisa suurte käivatesse</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Eemalda töölaualt</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Väljastage töölaual</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Eemalda dokkist</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Väljastage dokkisse</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Eemalda käivitamisega</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Lisa käivitamisega</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Kasuta proksi</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Keela näidiskülgede suurendamine</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Eemalda</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Makse</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Otsing</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Koko ekraani režiim</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Installi</translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Käsitavad kohalikult</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="254"/>
        <source>Window Mode</source>
        <translation>Aken režiim</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Vigla</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Muusika</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Vide</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Võtmed</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation>Mängud</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Tööriistad</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Lugemine</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Arendus</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Süsteem</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Muidud</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Loege välja</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Kinnita</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Uuesti installitud</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Kõik rakendused</translation>
    </message>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="557"/>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Otsingutulemusi pole</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Vaba järjendamine</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sorteeri kategooriate järgi</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sorteeri nime järgi</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Järjendamise režiim</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Arvutiga</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Pildid</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Dokumentid</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Töölaud</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Kontrollkeskus</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <location filename="../package/launcheritem.qml" line="111"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="113"/>
        <source>Chat</source>
        <translation>Väline</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="115"/>
        <source>Music</source>
        <translation>Müük</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="117"/>
        <source>Video</source>
        <translation>Vide</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="119"/>
        <source>Graphics</source>
        <translation>Vaatlejad</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="121"/>
        <source>Games</source>
        <translation>Mängud</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="123"/>
        <source>Office</source>
        <translation>Tööriistad</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="125"/>
        <source>Reading</source>
        <translation>Lulemine</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="127"/>
        <source>Development</source>
        <translation>Arendus</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="129"/>
        <source>System</source>
        <translation>Süsteem</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="131"/>
        <source>Others</source>
        <translation>Muidu</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="162"/>
        <source>launchpad</source>
        <translation>Lähtepunkt</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="309"/>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="321"/>
        <source>Cancel</source>
        <translation>Loetelu lõpetamine</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="335"/>
        <source>Confirm</source>
        <translation>Kinnita</translation>
    </message>
</context>
</TS>
